@@ -104,10 +104,12 @@ def GenerateHmacKey(file_name):
 
 # pylint: disable=R0913
 def GenerateClusterCrypto(new_cluster_cert, new_rapi_cert, new_spice_cert,
-                          new_confd_hmac_key, new_cds,
+                          new_confd_hmac_key, new_cds, new_client_cert,
+                          master_name,
                           rapi_cert_pem=None, spice_cert_pem=None,
                           spice_cacert_pem=None, cds=None,
                           nodecert_file=pathutils.NODED_CERT_FILE,
+                          clientcert_file=pathutils.NODED_CLIENT_CERT_FILE,
                           rapicert_file=pathutils.RAPI_CERT_FILE,
                           spicecert_file=pathutils.SPICE_CERT_FILE,
                           spicecacert_file=pathutils.SPICE_CACERT_FILE,
@@ -125,6 +127,10 @@ def GenerateClusterCrypto(new_cluster_cert, new_rapi_cert, new_spice_cert,
   @param new_confd_hmac_key: Whether to generate a new HMAC key
   @type new_cds: bool
   @param new_cds: Whether to generate a new cluster domain secret
+  @type new_client_cert: bool
+  @param new_client_cert: Whether to generate a new client certificate
+  @type master_name: string
+  @param master_name: FQDN of the master node
   @type rapi_cert_pem: string
   @param rapi_cert_pem: New RAPI certificate in PEM format
   @type spice_cert_pem: string
@@ -152,6 +158,12 @@ def GenerateClusterCrypto(new_cluster_cert, new_rapi_cert, new_spice_cert,
     new_cluster_cert, nodecert_file, 1,
     "Generating new cluster certificate at %s" % nodecert_file)
 
+  # If the cluster certificate was renewed, the client cert has to be
+  # renewed and resigned.
+  if new_cluster_cert or new_client_cert:
+    utils.GenerateNewClientSslCert(clientcert_file, nodecert_file,
+                                   master_name)
+
   # confd HMAC key
   if new_confd_hmac_key or not os.path.exists(hmackey_file):
     logging.debug("Writing new confd HMAC key to %s", hmackey_file)
@@ -202,7 +214,7 @@ def GenerateClusterCrypto(new_cluster_cert, new_rapi_cert, new_spice_cert,
     GenerateHmacKey(cds_file)
 
 
-def _InitGanetiServerSetup(master_name):
+def _InitGanetiServerSetup(master_name, cfg):
   """Setup the necessary configuration for the initial node daemon.
 
   This creates the nodepass file containing the shared password for
@@ -210,11 +222,35 @@ def _InitGanetiServerSetup(master_name):
 
   @type master_name: str
   @param master_name: Name of the master node
+  @type cfg: ConfigWriter
+  @param cfg: the configuration writer
 
   """
   # Generate cluster secrets
-  GenerateClusterCrypto(True, False, False, False, False)
+  GenerateClusterCrypto(True, False, False, False, False, False, master_name)
 
+  # Add the master's SSL certificate digest to the configuration.
+  master_uuid = cfg.GetMasterNode()
+  master_digest = utils.GetCertificateDigest()
+  cfg.AddNodeToCandidateCerts(master_uuid, master_digest)
+  cfg.Update(cfg.GetClusterInfo(), logging.error)
+  ssconf.WriteSsconfFiles(cfg.GetSsconfValues())
+
+  if not os.path.exists(
+      os.path.join(pathutils.DATA_DIR,
+      "%s%s" % (constants.SSCONF_FILEPREFIX,
+                constants.SS_MASTER_CANDIDATES_CERTS))):
+    raise errors.OpExecError("Ssconf file for master candidate certificates"
+                             " was not written.")
+
+  if not os.path.exists(pathutils.NODED_CERT_FILE):
+    raise errors.OpExecError("The server certficate was not created properly.")
+
+  if not os.path.exists(pathutils.NODED_CLIENT_CERT_FILE):
+    raise errors.OpExecError("The client certificate was not created"
+                             " properly.")
+
+  # set up the inter-node password and certificate
   result = utils.RunCmd([pathutils.DAEMON_UTIL, "start", constants.NODED])
   if result.failed:
     raise errors.OpExecError("Could not start the node daemon, command %s"
@@ -403,7 +439,7 @@ def _InitFileStorageDir(file_storage_dir):
 
 def _PrepareFileBasedStorage(
     enabled_disk_templates, file_storage_dir,
-    default_dir, file_disk_template,
+    default_dir, file_disk_template, _storage_path_acceptance_fn,
     init_fn=_InitFileStorageDir, acceptance_fn=None):
   """Checks if a file-base storage type is enabled and inits the dir.
 
@@ -415,14 +451,19 @@ def _PrepareFileBasedStorage(
   @param default_dir: default file storage directory when C{file_storage_dir}
       is 'None'
   @type file_disk_template: string
-  @param file_disk_template: a disk template whose storage type is 'ST_FILE' or
-      'ST_SHARED_FILE'
+  @param file_disk_template: a disk template whose storage type is 'ST_FILE',
+      'ST_SHARED_FILE' or 'ST_GLUSTER'
+  @type _storage_path_acceptance_fn: function
+  @param _storage_path_acceptance_fn: checks whether the given file-based
+      storage directory is acceptable
+  @see: C{cluster.CheckFileBasedStoragePathVsEnabledDiskTemplates} for details
+
   @rtype: string
   @returns: the name of the actual file storage directory
 
   """
   assert (file_disk_template in utils.storage.GetDiskTemplatesOfStorageTypes(
-            constants.ST_FILE, constants.ST_SHARED_FILE
+            constants.ST_FILE, constants.ST_SHARED_FILE, constants.ST_GLUSTER
          ))
 
   if file_storage_dir is None:
@@ -432,8 +473,8 @@ def _PrepareFileBasedStorage(
         lambda path: filestorage.CheckFileStoragePathAcceptance(
             path, exact_match_ok=True)
 
-  cluster.CheckFileStoragePathVsEnabledDiskTemplates(
-      logging.warning, file_storage_dir, enabled_disk_templates)
+  _storage_path_acceptance_fn(logging.warning, file_storage_dir,
+                              enabled_disk_templates)
 
   file_storage_enabled = file_disk_template in enabled_disk_templates
   if file_storage_enabled:
@@ -458,6 +499,7 @@ def _PrepareFileStorage(
   return _PrepareFileBasedStorage(
       enabled_disk_templates, file_storage_dir,
       pathutils.DEFAULT_FILE_STORAGE_DIR, constants.DT_FILE,
+      cluster.CheckFileStoragePathVsEnabledDiskTemplates,
       init_fn=init_fn, acceptance_fn=acceptance_fn)
 
 
@@ -472,6 +514,7 @@ def _PrepareSharedFileStorage(
   return _PrepareFileBasedStorage(
       enabled_disk_templates, file_storage_dir,
       pathutils.DEFAULT_SHARED_FILE_STORAGE_DIR, constants.DT_SHARED_FILE,
+      cluster.CheckSharedFileStoragePathVsEnabledDiskTemplates,
       init_fn=init_fn, acceptance_fn=acceptance_fn)
 
 
@@ -486,6 +529,7 @@ def _PrepareGlusterStorage(
   return _PrepareFileBasedStorage(
       enabled_disk_templates, file_storage_dir,
       pathutils.DEFAULT_GLUSTER_STORAGE_DIR, constants.DT_GLUSTER,
+      cluster.CheckGlusterStoragePathVsEnabledDiskTemplates,
       init_fn=init_fn, acceptance_fn=acceptance_fn)
 
 
@@ -682,6 +726,8 @@ def InitCluster(cluster_name, mac_prefix, # pylint: disable=R0913, R0914
                                          file_storage_dir)
   shared_file_storage_dir = _PrepareSharedFileStorage(enabled_disk_templates,
                                                       shared_file_storage_dir)
+  gluster_storage_dir = _PrepareGlusterStorage(enabled_disk_templates,
+                                               gluster_storage_dir)
 
   if not re.match("^[0-9a-z]{2}:[0-9a-z]{2}:[0-9a-z]{2}$", mac_prefix):
     raise errors.OpPrereqError("Invalid mac prefix given '%s'" % mac_prefix,
@@ -872,7 +918,7 @@ def InitCluster(cluster_name, mac_prefix, # pylint: disable=R0913, R0914
   ssconf.WriteSsconfFiles(cfg.GetSsconfValues())
 
   # set up the inter-node password and certificate
-  _InitGanetiServerSetup(hostname.name)
+  _InitGanetiServerSetup(hostname.name, cfg)
 
   logging.debug("Starting daemons")
   result = utils.RunCmd([pathutils.DAEMON_UTIL, "start-all"])
@@ -988,6 +1034,7 @@ def SetupNodeDaemon(opts, cluster_name, node, ssh_port):
       utils.ReadFile(pathutils.NODED_CERT_FILE),
     constants.NDS_SSCONF: ssconf.SimpleStore().ReadAll(),
     constants.NDS_START_NODE_DAEMON: True,
+    constants.NDS_NODE_NAME: node,
     }
 
   RunNodeSetupCmd(cluster_name, node, pathutils.NODE_DAEMON_SETUP,
