@@ -51,7 +51,7 @@ from ganeti.cmdlib.common import CheckParamsNotGlobal, \
   CheckInstanceState, INSTANCE_DOWN, GetUpdatedParams, \
   AdjustCandidatePool, CheckIAllocatorOrNode, LoadNodeEvacResult, \
   GetWantedNodes, MapInstanceLvsToNodes, RunPostHook, \
-  FindFaultyInstanceDisks, CheckStorageTypeEnabled, CreateNewClientCert, \
+  FindFaultyInstanceDisks, CheckStorageTypeEnabled, GetClientCertDigest, \
   AddNodeCertToCandidateCerts, RemoveNodeCertFromCandidateCerts, \
   EnsureKvmdOnNodes
 
@@ -431,7 +431,7 @@ class LUNodeAdd(LogicalUnit):
       RedistributeAncillaryFiles(self)
 
     # We create a new certificate even if the node is readded
-    digest = CreateNewClientCert(self, self.new_node.uuid)
+    digest = GetClientCertDigest(self, self.new_node.uuid)
     if self.new_node.master_candidate:
       self.cfg.AddNodeToCandidateCerts(self.new_node.uuid, digest)
     else:
@@ -1159,13 +1159,9 @@ def _GetStorageTypeArgs(cfg, storage_type):
   if storage_type == constants.ST_FILE:
     return [[cfg.GetFileStorageDir()]]
   elif storage_type == constants.ST_SHARED_FILE:
-    dts = cfg.GetClusterInfo().enabled_disk_templates
-    paths = []
-    if constants.DT_SHARED_FILE in dts:
-      paths.append(cfg.GetSharedFileStorageDir())
-    if constants.DT_GLUSTER in dts:
-      paths.append(cfg.GetGlusterStorageDir())
-    return [paths]
+    return [[cfg.GetSharedFileStorageDir()]]
+  elif storage_type == constants.ST_GLUSTER:
+    return [[cfg.GetGlusterStorageDir()]]
   else:
     return []
 
