@@ -72,7 +72,6 @@ from ganeti import cli
 from ganeti import rapi
 from ganeti import ht
 from ganeti import compat
-from ganeti import ssconf
 from ganeti.rapi import baserlib
 
 
@@ -238,7 +237,7 @@ class R_2_info(baserlib.OpcodeResource):
     """Returns cluster information.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
     return client.QueryClusterInfo()
 
 
@@ -297,6 +296,9 @@ class R_2_cluster_modify(baserlib.OpcodeResource):
 
   """
   PUT_OPCODE = opcodes.OpClusterSetParams
+  PUT_FORBIDDEN = [
+    "compression_tools",
+    ]
 
 
 class R_2_jobs(baserlib.ResourceBase):
@@ -309,7 +311,7 @@ class R_2_jobs(baserlib.ResourceBase):
     @return: a dictionary with jobs id and uri.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     if self.useBulk():
       bulkdata = client.QueryJobs(None, J_FIELDS_BULK)
@@ -338,7 +340,7 @@ class R_2_jobs_id(baserlib.ResourceBase):
 
     """
     job_id = self.items[0]
-    result = self.GetClient(query=True).QueryJobs([job_id, ], J_FIELDS)[0]
+    result = self.GetClient().QueryJobs([job_id, ], J_FIELDS)[0]
     if result is None:
       raise http.HttpNotFound()
     return baserlib.MapFields(J_FIELDS, result)
@@ -410,7 +412,7 @@ class R_2_nodes(baserlib.OpcodeResource):
     """Returns a list of all nodes.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     if self.useBulk():
       bulkdata = client.QueryNodes([], N_FIELDS, False)
@@ -435,7 +437,7 @@ class R_2_nodes_name(baserlib.OpcodeResource):
 
     """
     node_name = self.items[0]
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     result = baserlib.HandleItemQueryErrors(client.QueryNodes,
                                             names=[node_name], fields=N_FIELDS,
@@ -473,7 +475,7 @@ class R_2_nodes_name_role(baserlib.OpcodeResource):
 
     """
     node_name = self.items[0]
-    client = self.GetClient(query=True)
+    client = self.GetClient()
     result = client.QueryNodes(names=[node_name], fields=["role"],
                                use_locking=self.useLocking())
 
@@ -689,7 +691,7 @@ class R_2_networks(baserlib.OpcodeResource):
     """Returns a list of all networks.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     if self.useBulk():
       bulkdata = client.QueryNetworks([], NET_FIELDS, False)
@@ -712,7 +714,7 @@ class R_2_networks_name(baserlib.OpcodeResource):
 
     """
     network_name = self.items[0]
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     result = baserlib.HandleItemQueryErrors(client.QueryNetworks,
                                             names=[network_name],
@@ -805,7 +807,7 @@ class R_2_groups(baserlib.OpcodeResource):
     """Returns a list of all node groups.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     if self.useBulk():
       bulkdata = client.QueryGroups([], G_FIELDS, False)
@@ -828,7 +830,7 @@ class R_2_groups_name(baserlib.OpcodeResource):
 
     """
     group_name = self.items[0]
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     result = baserlib.HandleItemQueryErrors(client.QueryGroups,
                                             names=[group_name], fields=G_FIELDS,
@@ -938,7 +940,7 @@ class R_2_instances(baserlib.OpcodeResource):
     """Returns a list of all available instances.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     use_locking = self.useLocking()
     if self.useBulk():
@@ -1026,7 +1028,7 @@ class R_2_instances_name(baserlib.OpcodeResource):
     """Send information about an instance.
 
     """
-    client = self.GetClient(query=True)
+    client = self.GetClient()
     instance_name = self.items[0]
 
     result = baserlib.HandleItemQueryErrors(client.QueryInstances,
@@ -1279,7 +1281,7 @@ class R_2_instances_name_recreate_disks(baserlib.OpcodeResource):
     """Recreate disks for an instance.
 
     """
-    return ({}, {
+    return (self.request_body, {
       "instance_name": self.items[0],
       })
 
@@ -1416,7 +1418,7 @@ class R_2_instances_name_console(baserlib.ResourceBase):
 
     """
     instance_name = self.items[0]
-    client = self.GetClient(query=True)
+    client = self.GetClient()
 
     ((console, oper_state), ) = \
         client.QueryInstances([instance_name], ["console", "oper_state"], False)
@@ -1554,21 +1556,17 @@ class _R_Tags(baserlib.OpcodeResource):
     """
     kind = self.TAG_LEVEL
 
-    if kind in (constants.TAG_INSTANCE,
-                constants.TAG_NODEGROUP,
-                constants.TAG_NODE,
-                constants.TAG_NETWORK):
-      if not self.name:
-        raise http.HttpBadRequest("Missing name on tag request")
-
-      cl = self.GetClient(query=True)
-      tags = list(cl.QueryTags(kind, self.name))
-
-    elif kind == constants.TAG_CLUSTER:
-      assert not self.name
-      # TODO: Use query API?
-      ssc = ssconf.SimpleStore()
-      tags = ssc.GetClusterTags()
+    if kind in constants.VALID_TAG_TYPES:
+      cl = self.GetClient()
+      if kind == constants.TAG_CLUSTER:
+        if self.name:
+          raise http.HttpBadRequest("Can't specify a name"
+                                    " for cluster tag request")
+        tags = list(cl.QueryTags(kind, ""))
+      else:
+        if not self.name:
+          raise http.HttpBadRequest("Missing name on tag request")
+        tags = list(cl.QueryTags(kind, self.name))
 
     else:
       raise http.HttpBadRequest("Unhandled tag type!")
