@@ -99,6 +99,7 @@ module Ganeti.OpParams
   , pBackupCompress
   , pStartupPaused
   , pVerbose
+  , pDebug
   , pDebugSimulateErrors
   , pErrorCodes
   , pSkipChecks
@@ -554,6 +555,11 @@ pVerbose =
   withDoc "Verbose mode" $
   defaultFalse "verbose"
 
+pDebug :: Field
+pDebug =
+  withDoc "Debug mode" $
+  defaultFalse "debug"
+
 pOptGroupName :: Field
 pOptGroupName =
   withDoc "Optional group name" .
