@@ -157,7 +157,8 @@ instance Arbitrary OpCodes.OpCode where
       "OP_TAGS_DEL" ->
         arbitraryOpTagsDel
       "OP_CLUSTER_POST_INIT" -> pure OpCodes.OpClusterPostInit
-      "OP_CLUSTER_RENEW_CRYPTO" -> pure OpCodes.OpClusterRenewCrypto
+      "OP_CLUSTER_RENEW_CRYPTO" -> OpCodes.OpClusterRenewCrypto <$>
+         arbitrary <*> arbitrary
       "OP_CLUSTER_DESTROY" -> pure OpCodes.OpClusterDestroy
       "OP_CLUSTER_QUERY" -> pure OpCodes.OpClusterQuery
       "OP_CLUSTER_VERIFY" ->
@@ -678,7 +679,7 @@ prop_setOpComment op comment =
 prop_mkDiskIndex_fail :: QuickCheck.Positive Int -> Property
 prop_mkDiskIndex_fail (Positive i) =
   case mkDiskIndex (negate i) of
-    Bad msg -> printTestCase "error message " $
+    Bad msg -> counterexample "error message " $
                "Invalid value" `isPrefixOf` msg
     Ok v -> failTest $ "Succeeded to build disk index '" ++ show v ++
                        "' from negative value " ++ show (negate i)
