@@ -217,16 +217,7 @@ class TestLUClusterDestroy(CmdlibTestCase):
 
 class TestLUClusterPostInit(CmdlibTestCase):
 
-  @testutils.patch_object(cluster, "_UpdateMasterClientCert")
-  def testExecution(self, update_client_cert_mock):
-    # mock the client certificate creation as it is tested separately
-    update_client_cert_mock.return_value = None
-    # For the purpose of this test, return the same certificate digest for all
-    # nodes
-    self.rpc.call_node_crypto_tokens = \
-      lambda node_uuid, _: self.RpcResultsBuilder() \
-        .CreateSuccessfulNodeResult(node_uuid,
-          [(constants.CRYPTO_TYPE_SSL_DIGEST, "IA:MA:FA:KE:DI:GE:ST")])
+  def testExecution(self):
     op = opcodes.OpClusterPostInit()
 
     self.ExecOpCode(op)
@@ -487,6 +478,7 @@ class TestLUClusterSetParams(CmdlibTestCase):
   def testFileStorageDir(self):
     op = opcodes.OpClusterSetParams(file_storage_dir="/random/path")
     self.ExecOpCode(op)
+    self.assertEqual("/random/path", self.cluster.file_storage_dir)
 
   def testSetFileStorageDirToCurrentValue(self):
     op = opcodes.OpClusterSetParams(
@@ -511,6 +503,36 @@ class TestLUClusterSetParams(CmdlibTestCase):
     self.ExecOpCode(op)
     self.mcpu.assertLogContainsRegex("although file storage is not enabled")
 
+  def testSharedFileStorageDir(self):
+    op = opcodes.OpClusterSetParams(shared_file_storage_dir="/random/path")
+    self.ExecOpCode(op)
+    self.assertEqual("/random/path", self.cluster.shared_file_storage_dir)
+
+  def testSetSharedFileStorageDirToCurrentValue(self):
+    op = opcodes.OpClusterSetParams(shared_file_storage_dir="/random/path")
+    self.ExecOpCode(op)
+    op = opcodes.OpClusterSetParams(shared_file_storage_dir="/random/path")
+    self.ExecOpCode(op)
+    self.mcpu.assertLogContainsRegex("shared file storage dir already set to"
+                                     " value")
+
+  def testUnsetSharedFileStorageDirSharedFileStorageEnabled(self):
+    self.cfg.SetEnabledDiskTemplates([constants.DT_SHARED_FILE])
+    op = opcodes.OpClusterSetParams(shared_file_storage_dir='')
+    self.ExecOpCodeExpectOpPrereqError(op, "Unsetting the 'sharedfile' storage")
+
+  def testUnsetSharedFileStorageDirSharedFileStorageDisabled(self):
+    self.cfg.SetEnabledDiskTemplates([constants.DT_PLAIN])
+    op = opcodes.OpClusterSetParams(shared_file_storage_dir='')
+    self.ExecOpCode(op)
+
+  def testSetSharedFileStorageDirSharedFileStorageDisabled(self):
+    self.cfg.SetEnabledDiskTemplates([constants.DT_PLAIN])
+    op = opcodes.OpClusterSetParams(shared_file_storage_dir='/some/path/')
+    self.ExecOpCode(op)
+    self.mcpu.assertLogContainsRegex("although sharedfile storage is not"
+                                     " enabled")
+
   def testValidDrbdHelper(self):
     node1 = self.cfg.AddNewNode()
     node1.offline = True
@@ -2269,7 +2291,8 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
     shutil.copy(testutils.TestDataFilename("cert1.pem"), self._node_cert)
     self._client_node_cert = self._CreateTempFile()
     shutil.copy(testutils.TestDataFilename("cert2.pem"), self._client_node_cert)
-    self._client_node_cert_tmp = self._CreateTempFile()
+    self._client_node_cert_digest = \
+        "BF:24:F7:57:50:60:43:87:83:E3:0D:7E:EF:DD:14:6C:13:43:20:4E"
 
   def tearDown(self):
     super(TestLUClusterRenewCrypto, self).tearDown()
@@ -2290,8 +2313,6 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
     """
     pathutils.NODED_CERT_FILE = self._node_cert
     pathutils.NODED_CLIENT_CERT_FILE = self._client_node_cert
-    pathutils.NODED_CLIENT_CERT_FILE_TMP = \
-        self._client_node_cert_tmp
 
   def _AssertCertFiles(self, pathutils):
     """Check if the correct certificates exist and don't exist on the master.
@@ -2299,7 +2320,6 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
     """
     self.assertTrue(os.path.exists(pathutils.NODED_CERT_FILE))
     self.assertTrue(os.path.exists(pathutils.NODED_CLIENT_CERT_FILE))
-    self.assertFalse(os.path.exists(pathutils.NODED_CLIENT_CERT_FILE_TMP))
 
   def _CompletelySuccessfulRpc(self, node_uuid, _):
     """Fake RPC call which always returns successfully.
@@ -2329,27 +2349,17 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
     cluster = self.cfg.GetClusterInfo()
     self.assertEqual(num_nodes + 1, len(cluster.candidate_certs))
     nodes = self.cfg.GetAllNodesInfo()
-    for (node_uuid, _) in nodes.items():
-      expected_digest = self._GetFakeDigest(node_uuid)
-      self.assertEqual(expected_digest, cluster.candidate_certs[node_uuid])
-
-  @patchPathutils("cluster")
-  def testMasterFails(self, pathutils):
-    self._InitPathutils(pathutils)
-
-    # make sure the RPC calls are failing for all nodes
     master_uuid = self.cfg.GetMasterNode()
-    self.rpc.call_node_crypto_tokens.return_value = self.RpcResultsBuilder() \
-        .CreateFailedNodeResult(master_uuid)
-
-    op = opcodes.OpClusterRenewCrypto()
-    self.ExecOpCode(op)
-
-    self._AssertCertFiles(pathutils)
-
-    # Check if we correctly have no candidate certificates
-    cluster = self.cfg.GetClusterInfo()
-    self.assertFalse(cluster.candidate_certs)
+    for (node_uuid, _) in nodes.items():
+      if node_uuid == master_uuid:
+        # The master digest is from the actual test certificate.
+        self.assertEqual(self._client_node_cert_digest,
+                         cluster.candidate_certs[node_uuid])
+      else:
+        # The non-master nodes have the fake digest from the
+        # mock RPC.
+        expected_digest = self._GetFakeDigest(node_uuid)
+        self.assertEqual(expected_digest, cluster.candidate_certs[node_uuid])
 
   def _partiallyFailingRpc(self, node_uuid, _):
     if node_uuid == self._failed_node:
@@ -2390,8 +2400,7 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
       if node_uuid == self._failed_node:
         self.assertTrue(node_uuid not in cluster.candidate_certs)
       else:
-        expected_digest = self._GetFakeDigest(node_uuid)
-        self.assertEqual(expected_digest, cluster.candidate_certs[node_uuid])
+        self.assertTrue(node_uuid in cluster.candidate_certs)
 
   @patchPathutils("cluster")
   def testOfflineNodes(self, pathutils):
@@ -2419,8 +2428,7 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
       if node_info.offline == True:
         self.assertTrue(node_uuid not in cluster.candidate_certs)
       else:
-        expected_digest = self._GetFakeDigest(node_uuid)
-        self.assertEqual(expected_digest, cluster.candidate_certs[node_uuid])
+        self.assertTrue(node_uuid in cluster.candidate_certs)
 
   def _RpcSuccessfulAfterRetries(self, node_uuid, _):
     if self._retries < self._max_retries:
@@ -2432,40 +2440,6 @@ class TestLUClusterRenewCrypto(CmdlibTestCase):
         .CreateSuccessfulNodeResult(node_uuid,
           [(constants.CRYPTO_TYPE_SSL_DIGEST, self._GetFakeDigest(node_uuid))])
 
-  @patchPathutils("cluster")
-  def testMasterRetriesSuccess(self, pathutils):
-    self._InitPathutils(pathutils)
-
-    self._max_retries = 2
-    self._retries = 0
-    self.rpc.call_node_crypto_tokens = self._RpcSuccessfulAfterRetries
-
-    op = opcodes.OpClusterRenewCrypto()
-    self.ExecOpCode(op)
-
-    self._AssertCertFiles(pathutils)
-
-    cluster = self.cfg.GetClusterInfo()
-    master_uuid = self.cfg.GetMasterNode()
-    self.assertTrue(self._GetFakeDigest(master_uuid)
-                    in cluster.candidate_certs.values())
-
-  @patchPathutils("cluster")
-  def testMasterRetriesFail(self, pathutils):
-    self._InitPathutils(pathutils)
-
-    self._max_retries = 5
-    self._retries = 0
-    self.rpc.call_node_crypto_tokens = self._RpcSuccessfulAfterRetries
-
-    op = opcodes.OpClusterRenewCrypto()
-    self.ExecOpCode(op)
-
-    self._AssertCertFiles(pathutils)
-
-    cluster = self.cfg.GetClusterInfo()
-    self.assertFalse(cluster.candidate_certs)
-
   def _RpcSuccessfulAfterRetriesNonMaster(self, node_uuid, _):
     if self._retries < self._max_retries and node_uuid != self._master_uuid:
       self._retries += 1
