@@ -105,32 +105,6 @@ class TestGetCryptoTokens(testutils.GanetiTestCase):
     self.assertTrue((constants.CRYPTO_TYPE_SSL_DIGEST, self._ssl_digest)
                     in result)
 
-  def testCreateSslToken(self):
-    result = backend.GetCryptoTokens(
-      [(constants.CRYPTO_TYPE_SSL_DIGEST, constants.CRYPTO_ACTION_CREATE,
-        {constants.CRYPTO_OPTION_SERIAL_NO: 42})])
-    self.assertTrue((constants.CRYPTO_TYPE_SSL_DIGEST, self._ssl_digest)
-                    in result)
-    self.assertTrue(utils.GenerateNewSslCert.assert_calls().once())
-
-  def testCreateSslTokenDifferentFilename(self):
-    result = backend.GetCryptoTokens(
-      [(constants.CRYPTO_TYPE_SSL_DIGEST, constants.CRYPTO_ACTION_CREATE,
-        {constants.CRYPTO_OPTION_CERT_FILE:
-          pathutils.NODED_CLIENT_CERT_FILE_TMP,
-         constants.CRYPTO_OPTION_SERIAL_NO: 42})])
-    self.assertTrue((constants.CRYPTO_TYPE_SSL_DIGEST, self._ssl_digest)
-                    in result)
-    self.assertTrue(utils.GenerateNewSslCert.assert_calls().once())
-
-  def testCreateSslTokenSerialNo(self):
-    result = backend.GetCryptoTokens(
-      [(constants.CRYPTO_TYPE_SSL_DIGEST, constants.CRYPTO_ACTION_CREATE,
-        {constants.CRYPTO_OPTION_SERIAL_NO: 42})])
-    self.assertTrue((constants.CRYPTO_TYPE_SSL_DIGEST, self._ssl_digest)
-                    in result)
-    self.assertTrue(utils.GenerateNewSslCert.assert_calls().once())
-
   def testUnknownTokenType(self):
     self.assertRaises(errors.ProgrammerError,
                       backend.GetCryptoTokens,
@@ -203,7 +177,7 @@ class TestNodeVerify(testutils.GanetiTestCase):
     verif_cert.return_value = (None, None)
     cert_file = testutils.TestDataFilename("cert2.pem")
     (errcode, digest) = backend._VerifyClientCertificate(cert_file=cert_file)
-    self.assertEqual(None, errcode)
+    self.assertEqual(constants.CV_WARNING, errcode)
     self.assertTrue(isinstance(digest, str))
 
   @testutils.patch_object(utils, "VerifyCertificate")
